#==================================================================
# OOo2DBK : OpenOffice.org Writer document to DocBook XML converter
#==================================================================
# (C) Copyright 2004-2005 Nuxeo SARL <http://nuxeo.com>
# (C) Copyright Eric Bellot <ebellot@netcourrier.com>
#
# Authors:
# Ruslan Spivak (Nuxeo)
# M.-A. Darche (Nuxeo)
# Eric Bellot <ebellot@netcourrier.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#
# See ``COPYING`` for more information
#
# $Id: __init__.py 29929 2005-11-25 10:45:04Z madarche $
from ooo2dbk import convert, execArgs

